@@ -158,8 +158,8 @@ class Rely:
             return self.list()
         elif self.action == "template":
             return self.template()
-        elif self.action == "delete":
-            return self.delete()
+        # elif self.action == "delete":
+        #     return self.delete()
         else:
             return self.crud_mutation()
 
@@ -278,7 +278,10 @@ class Rely:
 
         result = gql_result[operation_name]
 
-        return first_value(result)
+        if "ok" not in result:
+            return first_value(result)
+        else:
+            return result
 
     def general_request(self):
         transport = self.client.transport
@@ -328,20 +331,20 @@ class Rely:
         result = first_value(gql_result)
         return filter_list_fields(result, query_type)
 
-    def delete(self):
-        mutation_name = self.get_type_mutation_name()
-        graphql = textwrap.dedent(
-            f"""
-            mutation($id: ID!) {{
-              {mutation_name}(input: {{
-                id: $id
-              }}) {{
-                ok
-              }}
-            }}
-            """
-        )
-        return self._execute(graphql)
+    # def delete(self):
+    #     mutation_name = self.get_type_mutation_name()
+    #     graphql = textwrap.dedent(
+    #         f"""
+    #         mutation($id: ID!) {{
+    #           {mutation_name}(input: {{
+    #             id: $id
+    #           }}) {{
+    #             ok
+    #           }}
+    #         }}
+    #         """
+    #     )
+    #     return self._execute(graphql)
 
     def template(self):
         operation_name = self.get_type_mutation_name("create")
